==> flyspray_0.9.6a.orig.tar.gz: flyspray-0.9.6/lang/it/register.php <==
<?php

global $register_text;
$register_text = array (

'registernewuser'	=>	'Registra nuovo utente',
'requiredfields'	=>	'I campi obbligatori sono identificati con un',
'username'			=>	'Username',
'password'			=>	'Password',
'confirmpass'		=>	'Conferma Password',
'realname'			=>	'Nome vero',
'emailaddress'		=>	'Indirizzo e-mail ',
'jabberid'			=>	'Jabber ID',
'notifications'		=>	'Notifiche',
'none'				=>	'Nessuna',
'email'				=>	'e-mail',
'jabber'			=>	'Jabber',
'note'				=>	'<b>Nota:</b>  Ti sara\' inviato un codice di conferma prima che il tuo account venga
creato. Il codice ti sara\' inviato usando il tuo metodo di notifica preferenziale, di sopra.<br>SE INSERISCI INFORMAZIONI FASULLE, NON RICEVERAI IL CODICE.',
'sendcode'			=>	'Invia il codice!',
'entercode'			=>	'Il tuo codice di conferma e\' stato inviato usando il tuo metodo di notifica preferenziale.  Quando lo ricevi, inseriscilo qui sotto.  Inserisci anche la password richiesta per l\'account.',
'confirmationcode'	=>	'Codice di conferma',
'registeraccount'	=>	'Registra questo account',
'registererror'		=>	'Accertati di avere riempito tutti i campi obbligatori, e di aver inserito i giusti dettagli per il
metodo di notifica preferenziale richiesto.',
'usernametaken'		=>	'Questo username &eacute; già stato scelto. Devi sceglierne un altro.',
'goback'			=>	'Torna indietro e fallo.',
'noticefrom'		=>	'Informazione da',
'addressused'		=>	'Questo indirizzo e\' stato usato per registrare un account Flyspray.  Se non stavi aspettando
questo messaggio, ti prego di ignorarlo e di cancellarlo. Il tuo codice di conferma e\':',

);
?>

==> flyspray_0.9.7.orig.tar.gz: flyspray-0.9.7/lang/it/register.php <==
<?php

global $register_text;
$register_text = array (

'registernewuser'	=>	'Registra nuovo utente',
'requiredfields'	=>	'I campi obbligatori sono identificati con un',
'username'			=>	'Username',
'password'			=>	'Password',
'confirmpass'		=>	'Conferma Password',
'realname'			=>	'Nome vero',
'emailaddress'		=>	'Indirizzo e-mail ',
'jabberid'			=>	'Jabber ID',
'notifications'		=>	'Notifiche',
'none'				=>	'Nessuna',
'email'				=>	'e-mail',
'jabber'			=>	'Jabber',
'note'				=>	'<b>Nota:</b>  Ti sara\' inviato un codice di conferma prima che il tuo account venga
creato. Il codice ti sara\' inviato usando il tuo metodo di notifica preferenziale, di sopra.<br>SE INSERISCI INFORMAZIONI FASULLE, NON RICEVERAI IL CODICE.',
'sendcode'			=>	'Invia il codice!',
'entercode'			=>	'Il tuo codice di conferma e\' stato inviato usando il tuo metodo di notifica preferenziale.  Quando lo ricevi, inseriscilo qui sotto.  Inserisci anche la password richiesta per l\'account.',
'confirmationcode'	=>	'Codice di conferma',
'registeraccount'	=>	'Registra questo account',
'registererror'		=>	'Accertati di avere riempito tutti i campi obbligatori, e di aver inserito i giusti dettagli per il
metodo di notifica preferenziale richiesto.',
'usernametaken'		=>	'Questo username &eacute; già stato scelto. Devi sceglierne un altro.',
'goback'			=>	'Torna indietro e fallo.',
'noticefrom'		=>	'Informazione da',
'addressused'		=>	'Questo indirizzo e\' stato usato per registrare un account Flyspray.  Se non stavi aspettando
questo messaggio, ti prego di ignorarlo e di cancellarlo. Il tuo codice di conferma e\':',

// Added in version 0.9.7
'badmagic'              =>      'Non è una chiave magica valida! Sei sicuro di averla presa dal tuo messaggio di notifica?',

);
?>
